Ext.namespace('Zarafa.owncloud.data');

/**
 * @class Zarafa.owncloud.data.DirectoryLoader
 * @extends Ext.tree.TreeLoader
 *
 * Owncloud Directory loader. Extends Ext treeloader to use Zarafa
 * specific requests.
 */
Zarafa.owncloud.data.DirectoryLoader = Ext.extend(Ext.tree.TreeLoader, {

	/**
	 * also load files
	 */
	files : false,
	
	/**
	 * @constructor
	 * @param {Object} config Configuration object
	 */
	constructor : function(config)
	{
		config = config || {};
		
		if(undefined !== config.loadfiles) {
			this.files = config.loadfiles;
		}

		Ext.applyIf(config, {
			directFn : this.loadFolder.createDelegate(this)
		});

		Zarafa.owncloud.data.DirectoryLoader.superclass.constructor.call(this, config);
	},

	/**
	 * Will do single request to owncloud module with provided nodeId and
	 * in case of success will load the content of this node.
	 *
	 * @param {Number} nodeId The id of node which content need to be loaded
	 * @param {Function} callback The function which need to be called after response received
	 */
	loadFolder : function(nodeId, callback)
	{
		var self = this;
		var responseHandler = new Zarafa.owncloud.data.ResponseHandler({
			successCallback: callback,
			nodeId: nodeId
		});
		
		container.getRequest().singleRequest(
			'owncloudmodule',
			'loaddirectory',
			{
				id : nodeId,
				loadfiles : this.files
			},
			responseHandler
		);
	}
});