Ext.namespace('Zarafa.owncloud.settings');

/**
 * @class Zarafa.owncloud.settings.SettingsOwncloudCategory
 * @extends Zarafa.settings.ui.SettingsCategory
 * @xtype zarafa.settingsowncloudcategory
 *
 * The owncloud category for users which will
 * allow the user to configure Owncloud related settings
 */
Zarafa.owncloud.settings.SettingsOwncloudCategory = Ext.extend(Zarafa.settings.ui.SettingsCategory, {
	// Insertion points for this class
	/**
	 * @insert context.settings.category.owncloud
	 * Insertion point to register new {@link Zarafa.settings.ui.SettingsWidget widgets}
	 * for the {@link Zarafa.owncloud.settings.SettingsOwncloudCategory Owncoud Category}.
	 * @param {Zarafa.owncloud.settings.SettingsOwncloudCategory} category The owncloud
	 * category to which the widgets will be added.
	 */

	/**
	 * @constructor
	 * @param {Object} config Configuration object
	 */
	constructor : function(config)
	{
		config = config || {};

		Ext.applyIf(config, {
			title : _('Owncloud'),
			categoryIndex : 1,
			iconCls : 'icon_owncloud_category',
			items : [{
				xtype : 'zarafa.settingsowncloudcomponentswidget'	// enable/disable plugins
			},{
				xtype : 'zarafa.settingsowncloudwidget'				// owncloud specific settings like server address...
			},{
				xtype : 'zarafa.settingsowncloudversionwidget'				// owncloud plugin version
			},
			container.populateInsertionPoint('context.settings.category.owncloud', this)
			]
		});

		Zarafa.owncloud.settings.SettingsOwncloudCategory.superclass.constructor.call(this, config);
	}
});

Ext.reg('zarafa.settingsowncloudcategory', Zarafa.owncloud.settings.SettingsOwncloudCategory);
